from typing import TYPE_CHECKING, Type, Optional, Sequence, Any

from ..const import Status
from ..utils import _cached

from .base import CodecBase, StatusDetailsCodecBase


if TYPE_CHECKING:
    from google.protobuf.message import Message  # noqa
    from .._typing import IProtoMessage  # noqa


@_cached
def _status_pb2() -> Any:
    from google.rpc import status_pb2
    return status_pb2


@_cached
def _sym_db() -> Any:
    from google.protobuf.symbol_database import Default
    return Default()  # type: ignore


@_cached
def _googleapis_available() -> bool:
    try:
        import google.rpc.status_pb2  # noqa
    except ImportError:
        return False
    else:
        return True


class ProtoCodec(CodecBase):
    __content_subtype__ = 'proto'

    def encode(
        self,
        message: 'IProtoMessage',
        message_type: Type['IProtoMessage'],
    ) -> bytes:
        if not isinstance(message, message_type):
            raise TypeError('Message must be of type {!r}, not {!r}'
                            .format(message_type, type(message)))
        return message.SerializeToString()

    def decode(
        self,
        data: bytes,
        message_type: Type['IProtoMessage'],
    ) -> 'IProtoMessage':
        return message_type.FromString(data)


class _Unknown:

    def __init__(self, name: str) -> None:
        self._name = name

    def __repr__(self) -> str:
        return 'Unknown({!r})'.format(self._name)


class ProtoStatusDetailsCodec(StatusDetailsCodecBase):

    def encode(
        self,
        status: Status,
        message: Optional[str],
        details: Sequence['Message'],
    ) -> bytes:
        status_pb2 = _status_pb2()

        status_proto = status_pb2.Status(code=status.value, message=message)
        if details is not None:
            for detail in details:
                detail_container = status_proto.details.add()
                detail_container.Pack(detail)
        return status_proto.SerializeToString()  # type: ignore

    def decode(
        self, status: Status, message: Optional[str], data: bytes,
    ) -> Sequence[Any]:
        status_pb2 = _status_pb2()
        sym_db = _sym_db()

        status_proto = status_pb2.Status.FromString(data)
        details = []
        for detail_container in status_proto.details:
            try:
                msg_type = sym_db.GetSymbol(detail_container.TypeName())
            except KeyError:
                details.append(_Unknown(detail_container.TypeName()))
                continue
            detail = msg_type()
            detail_container.Unpack(detail)
            details.append(detail)
        return details



from typing import Mapping, Any
from typing_extensions import Protocol

from . import const
from . import server


class IServable(Protocol):
    def __mapping__(self) -> Mapping[str, const.Handler]: ...


class ICheckable(Protocol):
    def __mapping__(self) -> Mapping[str, Any]: ...


class IClosable(Protocol):
    def close(self) -> None: ...


class IProtoMessage(Protocol):
    @classmethod
    def FromString(cls, s: bytes) -> 'IProtoMessage': ...

    def SerializeToString(self) -> bytes: ...


class IEventsTarget(Protocol):
    __dispatch__: Any  # FIXME: should be events._Dispatch


class IServerMethodFunc(Protocol):
    async def __call__(self, stream: 'server.Stream[Any, Any]') -> None: ...


class IReleaseStream(Protocol):
    def __call__(self) -> None: ...



import asyncio

from types import TracebackType
from typing import TYPE_CHECKING, Collection, Optional, Type

from .client import Channel
from .server import Server
from .encoding.base import CodecBase, StatusDetailsCodecBase

if TYPE_CHECKING:
    from ._typing import IServable  # noqa


class _Server(asyncio.AbstractServer):

    def close(self) -> None:
        pass

    async def wait_closed(self) -> None:
        pass


class _InMemoryTransport(asyncio.Transport):

    def __init__(
        self,
        protocol: asyncio.Protocol,
    ) -> None:
        super().__init__()
        self._loop = asyncio.get_event_loop()
        self._protocol = protocol

    def write(self, data: bytes) -> None:
        if data:
            self._loop.call_soon(self._protocol.data_received, data)

    def is_closing(self) -> bool:
        return False

    def close(self) -> None:
        pass


class ChannelFor:
    """Manages specially initialised :py:class:`~grpclib.client.Channel`
    with an in-memory transport to a :py:class:`~grpclib.server.Server`

    Example:

    .. code-block:: python3

        class Greeter(GreeterBase):
            ...

        greeter = Greeter()

        async with ChannelFor([greeter]) as channel:
            stub = GreeterStub(channel)
            response = await stub.SayHello(HelloRequest(name='Dr. Strange'))
            assert response.message == 'Hello, Dr. Strange!'
    """
    def __init__(
        self,
        services: Collection['IServable'],
        codec: Optional[CodecBase] = None,
        status_details_codec: Optional[StatusDetailsCodecBase] = None,
    ) -> None:
        """
        :param services: list of services you want to test

        :param codec: instance of a codec to encode and decode messages,
            if omitted ``ProtoCodec`` is used by default

        :param status_details_codec: instance of a status details codec to
            encode and decode error details in a trailing metadata, if omitted
            ``ProtoStatusDetailsCodec`` is used by default
        """
        self._services = services
        self._codec = codec
        self._status_details_codec = status_details_codec

    async def __aenter__(self) -> Channel:
        """
        :return: :py:class:`~grpclib.client.Channel`
        """
        self._server = Server(
            self._services,
            codec=self._codec,
            status_details_codec=self._status_details_codec,
        )
        self._server._server = _Server()
        self._server_protocol = self._server._protocol_factory()

        self._channel = Channel(
            codec=self._codec,
            status_details_codec=self._status_details_codec,
        )
        self._channel._protocol = self._channel._protocol_factory()

        self._channel._protocol.connection_made(
            _InMemoryTransport(self._server_protocol)
        )
        self._server_protocol.connection_made(
            _InMemoryTransport(self._channel._protocol)
        )
        return self._channel

    async def __aexit__(
        self,
        exc_type: Optional[Type[BaseException]],
        exc_val: Optional[BaseException],
        exc_tb: Optional[TracebackType],
    ) -> None:
        assert self._channel._protocol is not None
        self._channel._protocol.connection_lost(None)
        self._channel.close()

        self._server_protocol.connection_lost(None)
        self._server.close()
        await self._server.wait_closed()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: grpclib/channelz/v1/channelz.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='grpclib/channelz/v1/channelz.proto',
  package='grpc.channelz.v1',
  syntax='proto3',
  serialized_options=b'\n\023io.grpc.channelz.v1B\rChannelzProtoP\001Z0google.golang.org/grpc/channelz/grpc_channelz_v1',
  serialized_pb=b'\n\"grpclib/channelz/v1/channelz.proto\x12\x10grpc.channelz.v1\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\xfe\x01\n\x07\x43hannel\x12)\n\x03ref\x18\x01 \x01(\x0b\x32\x1c.grpc.channelz.v1.ChannelRef\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.grpc.channelz.v1.ChannelData\x12\x31\n\x0b\x63hannel_ref\x18\x03 \x03(\x0b\x32\x1c.grpc.channelz.v1.ChannelRef\x12\x37\n\x0esubchannel_ref\x18\x04 \x03(\x0b\x32\x1f.grpc.channelz.v1.SubchannelRef\x12/\n\nsocket_ref\x18\x05 \x03(\x0b\x32\x1b.grpc.channelz.v1.SocketRef\"\x84\x02\n\nSubchannel\x12,\n\x03ref\x18\x01 \x01(\x0b\x32\x1f.grpc.channelz.v1.SubchannelRef\x12+\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1d.grpc.channelz.v1.ChannelData\x12\x31\n\x0b\x63hannel_ref\x18\x03 \x03(\x0b\x32\x1c.grpc.channelz.v1.ChannelRef\x12\x37\n\x0esubchannel_ref\x18\x04 \x03(\x0b\x32\x1f.grpc.channelz.v1.SubchannelRef\x12/\n\nsocket_ref\x18\x05 \x03(\x0b\x32\x1b.grpc.channelz.v1.SocketRef\"\xbb\x01\n\x18\x43hannelConnectivityState\x12?\n\x05state\x18\x01 \x01(\x0e\x32\x30.grpc.channelz.v1.ChannelConnectivityState.State\"^\n\x05State\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04IDLE\x10\x01\x12\x0e\n\nCONNECTING\x10\x02\x12\t\n\x05READY\x10\x03\x12\x15\n\x11TRANSIENT_FAILURE\x10\x04\x12\x0c\n\x08SHUTDOWN\x10\x05\"\x8e\x02\n\x0b\x43hannelData\x12\x39\n\x05state\x18\x01 \x01(\x0b\x32*.grpc.channelz.v1.ChannelConnectivityState\x12\x0e\n\x06target\x18\x02 \x01(\t\x12-\n\x05trace\x18\x03 \x01(\x0b\x32\x1e.grpc.channelz.v1.ChannelTrace\x12\x15\n\rcalls_started\x18\x04 \x01(\x03\x12\x17\n\x0f\x63\x61lls_succeeded\x18\x05 \x01(\x03\x12\x14\n\x0c\x63\x61lls_failed\x18\x06 \x01(\x03\x12?\n\x1blast_call_started_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xdb\x02\n\x11\x43hannelTraceEvent\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12>\n\x08severity\x18\x02 \x01(\x0e\x32,.grpc.channelz.v1.ChannelTraceEvent.Severity\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x0b\x63hannel_ref\x18\x04 \x01(\x0b\x32\x1c.grpc.channelz.v1.ChannelRefH\x00\x12\x39\n\x0esubchannel_ref\x18\x05 \x01(\x0b\x32\x1f.grpc.channelz.v1.SubchannelRefH\x00\"E\n\x08Severity\x12\x0e\n\nCT_UNKNOWN\x10\x00\x12\x0b\n\x07\x43T_INFO\x10\x01\x12\x0e\n\nCT_WARNING\x10\x02\x12\x0c\n\x08\x43T_ERROR\x10\x03\x42\x0b\n\tchild_ref\"\x96\x01\n\x0c\x43hannelTrace\x12\x19\n\x11num_events_logged\x18\x01 \x01(\x03\x12\x36\n\x12\x63reation_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x33\n\x06\x65vents\x18\x03 \x03(\x0b\x32#.grpc.channelz.v1.ChannelTraceEvent\"R\n\nChannelRef\x12\x12\n\nchannel_id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\tJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\t\"X\n\rSubchannelRef\x12\x15\n\rsubchannel_id\x18\x07 \x01(\x03\x12\x0c\n\x04name\x18\x08 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07\"P\n\tSocketRef\x12\x11\n\tsocket_id\x18\x03 \x01(\x03\x12\x0c\n\x04name\x18\x04 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\t\"P\n\tServerRef\x12\x11\n\tserver_id\x18\x05 \x01(\x03\x12\x0c\n\x04name\x18\x06 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\t\"\x92\x01\n\x06Server\x12(\n\x03ref\x18\x01 \x01(\x0b\x32\x1b.grpc.channelz.v1.ServerRef\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.grpc.channelz.v1.ServerData\x12\x32\n\rlisten_socket\x18\x03 \x03(\x0b\x32\x1b.grpc.channelz.v1.SocketRef\"\xc2\x01\n\nServerData\x12-\n\x05trace\x18\x01 \x01(\x0b\x32\x1e.grpc.channelz.v1.ChannelTrace\x12\x15\n\rcalls_started\x18\x02 \x01(\x03\x12\x17\n\x0f\x63\x61lls_succeeded\x18\x03 \x01(\x03\x12\x14\n\x0c\x63\x61lls_failed\x18\x04 \x01(\x03\x12?\n\x1blast_call_started_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xf6\x01\n\x06Socket\x12(\n\x03ref\x18\x01 \x01(\x0b\x32\x1b.grpc.channelz.v1.SocketRef\x12*\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x1c.grpc.channelz.v1.SocketData\x12(\n\x05local\x18\x03 \x01(\x0b\x32\x19.grpc.channelz.v1.Address\x12)\n\x06remote\x18\x04 \x01(\x0b\x32\x19.grpc.channelz.v1.Address\x12,\n\x08security\x18\x05 \x01(\x0b\x32\x1a.grpc.channelz.v1.Security\x12\x13\n\x0bremote_name\x18\x06 \x01(\t\"\xee\x04\n\nSocketData\x12\x17\n\x0fstreams_started\x18\x01 \x01(\x03\x12\x19\n\x11streams_succeeded\x18\x02 \x01(\x03\x12\x16\n\x0estreams_failed\x18\x03 \x01(\x03\x12\x15\n\rmessages_sent\x18\x04 \x01(\x03\x12\x19\n\x11messages_received\x18\x05 \x01(\x03\x12\x18\n\x10keep_alives_sent\x18\x06 \x01(\x03\x12G\n#last_local_stream_created_timestamp\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12H\n$last_remote_stream_created_timestamp\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12?\n\x1blast_message_sent_timestamp\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x43\n\x1flast_message_received_timestamp\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12>\n\x19local_flow_control_window\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12?\n\x1aremote_flow_control_window\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12.\n\x06option\x18\r \x03(\x0b\x32\x1e.grpc.channelz.v1.SocketOption\"\xe8\x02\n\x07\x41\x64\x64ress\x12?\n\rtcpip_address\x18\x01 \x01(\x0b\x32&.grpc.channelz.v1.Address.TcpIpAddressH\x00\x12;\n\x0buds_address\x18\x02 \x01(\x0b\x32$.grpc.channelz.v1.Address.UdsAddressH\x00\x12?\n\rother_address\x18\x03 \x01(\x0b\x32&.grpc.channelz.v1.Address.OtherAddressH\x00\x1a\x30\n\x0cTcpIpAddress\x12\x12\n\nip_address\x18\x01 \x01(\x0c\x12\x0c\n\x04port\x18\x02 \x01(\x05\x1a\x1e\n\nUdsAddress\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x1a\x41\n\x0cOtherAddress\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\t\n\x07\x61\x64\x64ress\"\xbe\x02\n\x08Security\x12-\n\x03tls\x18\x01 \x01(\x0b\x32\x1e.grpc.channelz.v1.Security.TlsH\x00\x12\x39\n\x05other\x18\x02 \x01(\x0b\x32(.grpc.channelz.v1.Security.OtherSecurityH\x00\x1a{\n\x03Tls\x12\x17\n\rstandard_name\x18\x01 \x01(\tH\x00\x12\x14\n\nother_name\x18\x02 \x01(\tH\x00\x12\x19\n\x11local_certificate\x18\x03 \x01(\x0c\x12\x1a\n\x12remote_certificate\x18\x04 \x01(\x0c\x42\x0e\n\x0c\x63ipher_suite\x1a\x42\n\rOtherSecurity\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.google.protobuf.AnyB\x07\n\x05model\"U\n\x0cSocketOption\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12(\n\nadditional\x18\x03 \x01(\x0b\x32\x14.google.protobuf.Any\"B\n\x13SocketOptionTimeout\x12+\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\"Q\n\x12SocketOptionLinger\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12+\n\x08\x64uration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xae\x05\n\x13SocketOptionTcpInfo\x12\x12\n\ntcpi_state\x18\x01 \x01(\r\x12\x15\n\rtcpi_ca_state\x18\x02 \x01(\r\x12\x18\n\x10tcpi_retransmits\x18\x03 \x01(\r\x12\x13\n\x0btcpi_probes\x18\x04 \x01(\r\x12\x14\n\x0ctcpi_backoff\x18\x05 \x01(\r\x12\x14\n\x0ctcpi_options\x18\x06 \x01(\r\x12\x17\n\x0ftcpi_snd_wscale\x18\x07 \x01(\r\x12\x17\n\x0ftcpi_rcv_wscale\x18\x08 \x01(\r\x12\x10\n\x08tcpi_rto\x18\t \x01(\r\x12\x10\n\x08tcpi_ato\x18\n \x01(\r\x12\x14\n\x0ctcpi_snd_mss\x18\x0b \x01(\r\x12\x14\n\x0ctcpi_rcv_mss\x18\x0c \x01(\r\x12\x14\n\x0ctcpi_unacked\x18\r \x01(\r\x12\x13\n\x0btcpi_sacked\x18\x0e \x01(\r\x12\x11\n\ttcpi_lost\x18\x0f \x01(\r\x12\x14\n\x0ctcpi_retrans\x18\x10 \x01(\r\x12\x14\n\x0ctcpi_fackets\x18\x11 \x01(\r\x12\x1b\n\x13tcpi_last_data_sent\x18\x12 \x01(\r\x12\x1a\n\x12tcpi_last_ack_sent\x18\x13 \x01(\r\x12\x1b\n\x13tcpi_last_data_recv\x18\x14 \x01(\r\x12\x1a\n\x12tcpi_last_ack_recv\x18\x15 \x01(\r\x12\x11\n\ttcpi_pmtu\x18\x16 \x01(\r\x12\x19\n\x11tcpi_rcv_ssthresh\x18\x17 \x01(\r\x12\x10\n\x08tcpi_rtt\x18\x18 \x01(\r\x12\x13\n\x0btcpi_rttvar\x18\x19 \x01(\r\x12\x19\n\x11tcpi_snd_ssthresh\x18\x1a \x01(\r\x12\x15\n\rtcpi_snd_cwnd\x18\x1b \x01(\r\x12\x13\n\x0btcpi_advmss\x18\x1c \x01(\r\x12\x17\n\x0ftcpi_reordering\x18\x1d \x01(\r\"F\n\x15GetTopChannelsRequest\x12\x18\n\x10start_channel_id\x18\x01 \x01(\x03\x12\x13\n\x0bmax_results\x18\x02 \x01(\x03\"Q\n\x16GetTopChannelsResponse\x12*\n\x07\x63hannel\x18\x01 \x03(\x0b\x32\x19.grpc.channelz.v1.Channel\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x08\"A\n\x11GetServersRequest\x12\x17\n\x0fstart_server_id\x18\x01 \x01(\x03\x12\x13\n\x0bmax_results\x18\x02 \x01(\x03\"K\n\x12GetServersResponse\x12(\n\x06server\x18\x01 \x03(\x0b\x32\x18.grpc.channelz.v1.Server\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x08\"%\n\x10GetServerRequest\x12\x11\n\tserver_id\x18\x01 \x01(\x03\"=\n\x11GetServerResponse\x12(\n\x06server\x18\x01 \x01(\x0b\x32\x18.grpc.channelz.v1.Server\"Z\n\x17GetServerSocketsRequest\x12\x11\n\tserver_id\x18\x01 \x01(\x03\x12\x17\n\x0fstart_socket_id\x18\x02 \x01(\x03\x12\x13\n\x0bmax_results\x18\x03 \x01(\x03\"X\n\x18GetServerSocketsResponse\x12/\n\nsocket_ref\x18\x01 \x03(\x0b\x32\x1b.grpc.channelz.v1.SocketRef\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x08\"\'\n\x11GetChannelRequest\x12\x12\n\nchannel_id\x18\x01 \x01(\x03\"@\n\x12GetChannelResponse\x12*\n\x07\x63hannel\x18\x01 \x01(\x0b\x32\x19.grpc.channelz.v1.Channel\"-\n\x14GetSubchannelRequest\x12\x15\n\rsubchannel_id\x18\x01 \x01(\x03\"I\n\x15GetSubchannelResponse\x12\x30\n\nsubchannel\x18\x01 \x01(\x0b\x32\x1c.grpc.channelz.v1.Subchannel\"6\n\x10GetSocketRequest\x12\x11\n\tsocket_id\x18\x01 \x01(\x03\x12\x0f\n\x07summary\x18\x02 \x01(\x08\"=\n\x11GetSocketResponse\x12(\n\x06socket\x18\x01 \x01(\x0b\x32\x18.grpc.channelz.v1.Socket2\x9a\x05\n\x08\x43hannelz\x12\x63\n\x0eGetTopChannels\x12\'.grpc.channelz.v1.GetTopChannelsRequest\x1a(.grpc.channelz.v1.GetTopChannelsResponse\x12W\n\nGetServers\x12#.grpc.channelz.v1.GetServersRequest\x1a$.grpc.channelz.v1.GetServersResponse\x12T\n\tGetServer\x12\".grpc.channelz.v1.GetServerRequest\x1a#.grpc.channelz.v1.GetServerResponse\x12i\n\x10GetServerSockets\x12).grpc.channelz.v1.GetServerSocketsRequest\x1a*.grpc.channelz.v1.GetServerSocketsResponse\x12W\n\nGetChannel\x12#.grpc.channelz.v1.GetChannelRequest\x1a$.grpc.channelz.v1.GetChannelResponse\x12`\n\rGetSubchannel\x12&.grpc.channelz.v1.GetSubchannelRequest\x1a\'.grpc.channelz.v1.GetSubchannelResponse\x12T\n\tGetSocket\x12\".grpc.channelz.v1.GetSocketRequest\x1a#.grpc.channelz.v1.GetSocketResponseBX\n\x13io.grpc.channelz.v1B\rChannelzProtoP\x01Z0google.golang.org/grpc/channelz/grpc_channelz_v1b\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])



_CHANNELCONNECTIVITYSTATE_STATE = _descriptor.EnumDescriptor(
  name='State',
  full_name='grpc.channelz.v1.ChannelConnectivityState.State',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IDLE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONNECTING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='READY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRANSIENT_FAILURE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHUTDOWN', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=794,
  serialized_end=888,
)
_sym_db.RegisterEnumDescriptor(_CHANNELCONNECTIVITYSTATE_STATE)

_CHANNELTRACEEVENT_SEVERITY = _descriptor.EnumDescriptor(
  name='Severity',
  full_name='grpc.channelz.v1.ChannelTraceEvent.Severity',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CT_UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_INFO', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_WARNING', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CT_ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1429,
  serialized_end=1498,
)
_sym_db.RegisterEnumDescriptor(_CHANNELTRACEEVENT_SEVERITY)


_CHANNEL = _descriptor.Descriptor(
  name='Channel',
  full_name='grpc.channelz.v1.Channel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ref', full_name='grpc.channelz.v1.Channel.ref', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='grpc.channelz.v1.Channel.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_ref', full_name='grpc.channelz.v1.Channel.channel_ref', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subchannel_ref', full_name='grpc.channelz.v1.Channel.subchannel_ref', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='socket_ref', full_name='grpc.channelz.v1.Channel.socket_ref', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=181,
  serialized_end=435,
)


_SUBCHANNEL = _descriptor.Descriptor(
  name='Subchannel',
  full_name='grpc.channelz.v1.Subchannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ref', full_name='grpc.channelz.v1.Subchannel.ref', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='grpc.channelz.v1.Subchannel.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_ref', full_name='grpc.channelz.v1.Subchannel.channel_ref', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subchannel_ref', full_name='grpc.channelz.v1.Subchannel.subchannel_ref', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='socket_ref', full_name='grpc.channelz.v1.Subchannel.socket_ref', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=438,
  serialized_end=698,
)


_CHANNELCONNECTIVITYSTATE = _descriptor.Descriptor(
  name='ChannelConnectivityState',
  full_name='grpc.channelz.v1.ChannelConnectivityState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='grpc.channelz.v1.ChannelConnectivityState.state', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHANNELCONNECTIVITYSTATE_STATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=701,
  serialized_end=888,
)


_CHANNELDATA = _descriptor.Descriptor(
  name='ChannelData',
  full_name='grpc.channelz.v1.ChannelData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='grpc.channelz.v1.ChannelData.state', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='target', full_name='grpc.channelz.v1.ChannelData.target', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trace', full_name='grpc.channelz.v1.ChannelData.trace', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calls_started', full_name='grpc.channelz.v1.ChannelData.calls_started', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calls_succeeded', full_name='grpc.channelz.v1.ChannelData.calls_succeeded', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calls_failed', full_name='grpc.channelz.v1.ChannelData.calls_failed', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_call_started_timestamp', full_name='grpc.channelz.v1.ChannelData.last_call_started_timestamp', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=891,
  serialized_end=1161,
)


_CHANNELTRACEEVENT = _descriptor.Descriptor(
  name='ChannelTraceEvent',
  full_name='grpc.channelz.v1.ChannelTraceEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='description', full_name='grpc.channelz.v1.ChannelTraceEvent.description', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='severity', full_name='grpc.channelz.v1.ChannelTraceEvent.severity', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='grpc.channelz.v1.ChannelTraceEvent.timestamp', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='channel_ref', full_name='grpc.channelz.v1.ChannelTraceEvent.channel_ref', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='subchannel_ref', full_name='grpc.channelz.v1.ChannelTraceEvent.subchannel_ref', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CHANNELTRACEEVENT_SEVERITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='child_ref', full_name='grpc.channelz.v1.ChannelTraceEvent.child_ref',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1164,
  serialized_end=1511,
)


_CHANNELTRACE = _descriptor.Descriptor(
  name='ChannelTrace',
  full_name='grpc.channelz.v1.ChannelTrace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_events_logged', full_name='grpc.channelz.v1.ChannelTrace.num_events_logged', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creation_timestamp', full_name='grpc.channelz.v1.ChannelTrace.creation_timestamp', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='events', full_name='grpc.channelz.v1.ChannelTrace.events', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1514,
  serialized_end=1664,
)


_CHANNELREF = _descriptor.Descriptor(
  name='ChannelRef',
  full_name='grpc.channelz.v1.ChannelRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='grpc.channelz.v1.ChannelRef.channel_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='grpc.channelz.v1.ChannelRef.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1666,
  serialized_end=1748,
)


_SUBCHANNELREF = _descriptor.Descriptor(
  name='SubchannelRef',
  full_name='grpc.channelz.v1.SubchannelRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subchannel_id', full_name='grpc.channelz.v1.SubchannelRef.subchannel_id', index=0,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='grpc.channelz.v1.SubchannelRef.name', index=1,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1750,
  serialized_end=1838,
)


_SOCKETREF = _descriptor.Descriptor(
  name='SocketRef',
  full_name='grpc.channelz.v1.SocketRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket_id', full_name='grpc.channelz.v1.SocketRef.socket_id', index=0,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='grpc.channelz.v1.SocketRef.name', index=1,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1840,
  serialized_end=1920,
)


_SERVERREF = _descriptor.Descriptor(
  name='ServerRef',
  full_name='grpc.channelz.v1.ServerRef',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_id', full_name='grpc.channelz.v1.ServerRef.server_id', index=0,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='grpc.channelz.v1.ServerRef.name', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1922,
  serialized_end=2002,
)


_SERVER = _descriptor.Descriptor(
  name='Server',
  full_name='grpc.channelz.v1.Server',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ref', full_name='grpc.channelz.v1.Server.ref', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='grpc.channelz.v1.Server.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='listen_socket', full_name='grpc.channelz.v1.Server.listen_socket', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2005,
  serialized_end=2151,
)


_SERVERDATA = _descriptor.Descriptor(
  name='ServerData',
  full_name='grpc.channelz.v1.ServerData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trace', full_name='grpc.channelz.v1.ServerData.trace', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calls_started', full_name='grpc.channelz.v1.ServerData.calls_started', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calls_succeeded', full_name='grpc.channelz.v1.ServerData.calls_succeeded', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='calls_failed', full_name='grpc.channelz.v1.ServerData.calls_failed', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_call_started_timestamp', full_name='grpc.channelz.v1.ServerData.last_call_started_timestamp', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2154,
  serialized_end=2348,
)


_SOCKET = _descriptor.Descriptor(
  name='Socket',
  full_name='grpc.channelz.v1.Socket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ref', full_name='grpc.channelz.v1.Socket.ref', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='grpc.channelz.v1.Socket.data', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local', full_name='grpc.channelz.v1.Socket.local', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote', full_name='grpc.channelz.v1.Socket.remote', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='security', full_name='grpc.channelz.v1.Socket.security', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote_name', full_name='grpc.channelz.v1.Socket.remote_name', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2351,
  serialized_end=2597,
)


_SOCKETDATA = _descriptor.Descriptor(
  name='SocketData',
  full_name='grpc.channelz.v1.SocketData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streams_started', full_name='grpc.channelz.v1.SocketData.streams_started', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streams_succeeded', full_name='grpc.channelz.v1.SocketData.streams_succeeded', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streams_failed', full_name='grpc.channelz.v1.SocketData.streams_failed', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='messages_sent', full_name='grpc.channelz.v1.SocketData.messages_sent', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='messages_received', full_name='grpc.channelz.v1.SocketData.messages_received', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keep_alives_sent', full_name='grpc.channelz.v1.SocketData.keep_alives_sent', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_local_stream_created_timestamp', full_name='grpc.channelz.v1.SocketData.last_local_stream_created_timestamp', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_remote_stream_created_timestamp', full_name='grpc.channelz.v1.SocketData.last_remote_stream_created_timestamp', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_message_sent_timestamp', full_name='grpc.channelz.v1.SocketData.last_message_sent_timestamp', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_message_received_timestamp', full_name='grpc.channelz.v1.SocketData.last_message_received_timestamp', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_flow_control_window', full_name='grpc.channelz.v1.SocketData.local_flow_control_window', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote_flow_control_window', full_name='grpc.channelz.v1.SocketData.remote_flow_control_window', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='option', full_name='grpc.channelz.v1.SocketData.option', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2600,
  serialized_end=3222,
)


_ADDRESS_TCPIPADDRESS = _descriptor.Descriptor(
  name='TcpIpAddress',
  full_name='grpc.channelz.v1.Address.TcpIpAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip_address', full_name='grpc.channelz.v1.Address.TcpIpAddress.ip_address', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='grpc.channelz.v1.Address.TcpIpAddress.port', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3427,
  serialized_end=3475,
)

_ADDRESS_UDSADDRESS = _descriptor.Descriptor(
  name='UdsAddress',
  full_name='grpc.channelz.v1.Address.UdsAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='grpc.channelz.v1.Address.UdsAddress.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3477,
  serialized_end=3507,
)

_ADDRESS_OTHERADDRESS = _descriptor.Descriptor(
  name='OtherAddress',
  full_name='grpc.channelz.v1.Address.OtherAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grpc.channelz.v1.Address.OtherAddress.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='grpc.channelz.v1.Address.OtherAddress.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3509,
  serialized_end=3574,
)

_ADDRESS = _descriptor.Descriptor(
  name='Address',
  full_name='grpc.channelz.v1.Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tcpip_address', full_name='grpc.channelz.v1.Address.tcpip_address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uds_address', full_name='grpc.channelz.v1.Address.uds_address', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='other_address', full_name='grpc.channelz.v1.Address.other_address', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ADDRESS_TCPIPADDRESS, _ADDRESS_UDSADDRESS, _ADDRESS_OTHERADDRESS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address', full_name='grpc.channelz.v1.Address.address',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3225,
  serialized_end=3585,
)


_SECURITY_TLS = _descriptor.Descriptor(
  name='Tls',
  full_name='grpc.channelz.v1.Security.Tls',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='standard_name', full_name='grpc.channelz.v1.Security.Tls.standard_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='other_name', full_name='grpc.channelz.v1.Security.Tls.other_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_certificate', full_name='grpc.channelz.v1.Security.Tls.local_certificate', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remote_certificate', full_name='grpc.channelz.v1.Security.Tls.remote_certificate', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='cipher_suite', full_name='grpc.channelz.v1.Security.Tls.cipher_suite',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3706,
  serialized_end=3829,
)

_SECURITY_OTHERSECURITY = _descriptor.Descriptor(
  name='OtherSecurity',
  full_name='grpc.channelz.v1.Security.OtherSecurity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grpc.channelz.v1.Security.OtherSecurity.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='grpc.channelz.v1.Security.OtherSecurity.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3831,
  serialized_end=3897,
)

_SECURITY = _descriptor.Descriptor(
  name='Security',
  full_name='grpc.channelz.v1.Security',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tls', full_name='grpc.channelz.v1.Security.tls', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='other', full_name='grpc.channelz.v1.Security.other', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_SECURITY_TLS, _SECURITY_OTHERSECURITY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='model', full_name='grpc.channelz.v1.Security.model',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3588,
  serialized_end=3906,
)


_SOCKETOPTION = _descriptor.Descriptor(
  name='SocketOption',
  full_name='grpc.channelz.v1.SocketOption',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='grpc.channelz.v1.SocketOption.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='grpc.channelz.v1.SocketOption.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='additional', full_name='grpc.channelz.v1.SocketOption.additional', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3908,
  serialized_end=3993,
)


_SOCKETOPTIONTIMEOUT = _descriptor.Descriptor(
  name='SocketOptionTimeout',
  full_name='grpc.channelz.v1.SocketOptionTimeout',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='duration', full_name='grpc.channelz.v1.SocketOptionTimeout.duration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3995,
  serialized_end=4061,
)


_SOCKETOPTIONLINGER = _descriptor.Descriptor(
  name='SocketOptionLinger',
  full_name='grpc.channelz.v1.SocketOptionLinger',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='active', full_name='grpc.channelz.v1.SocketOptionLinger.active', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='grpc.channelz.v1.SocketOptionLinger.duration', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4063,
  serialized_end=4144,
)


_SOCKETOPTIONTCPINFO = _descriptor.Descriptor(
  name='SocketOptionTcpInfo',
  full_name='grpc.channelz.v1.SocketOptionTcpInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tcpi_state', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_state', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_ca_state', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_ca_state', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_retransmits', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_retransmits', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_probes', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_probes', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_backoff', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_backoff', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_options', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_options', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_snd_wscale', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_snd_wscale', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_rcv_wscale', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_rcv_wscale', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_rto', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_rto', index=8,
      number=9, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_ato', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_ato', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_snd_mss', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_snd_mss', index=10,
      number=11, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_rcv_mss', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_rcv_mss', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_unacked', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_unacked', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_sacked', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_sacked', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_lost', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_lost', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_retrans', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_retrans', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_fackets', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_fackets', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_last_data_sent', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_last_data_sent', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_last_ack_sent', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_last_ack_sent', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_last_data_recv', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_last_data_recv', index=19,
      number=20, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_last_ack_recv', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_last_ack_recv', index=20,
      number=21, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_pmtu', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_pmtu', index=21,
      number=22, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_rcv_ssthresh', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_rcv_ssthresh', index=22,
      number=23, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_rtt', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_rtt', index=23,
      number=24, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_rttvar', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_rttvar', index=24,
      number=25, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_snd_ssthresh', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_snd_ssthresh', index=25,
      number=26, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_snd_cwnd', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_snd_cwnd', index=26,
      number=27, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_advmss', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_advmss', index=27,
      number=28, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tcpi_reordering', full_name='grpc.channelz.v1.SocketOptionTcpInfo.tcpi_reordering', index=28,
      number=29, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4147,
  serialized_end=4833,
)


_GETTOPCHANNELSREQUEST = _descriptor.Descriptor(
  name='GetTopChannelsRequest',
  full_name='grpc.channelz.v1.GetTopChannelsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_channel_id', full_name='grpc.channelz.v1.GetTopChannelsRequest.start_channel_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='grpc.channelz.v1.GetTopChannelsRequest.max_results', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4835,
  serialized_end=4905,
)


_GETTOPCHANNELSRESPONSE = _descriptor.Descriptor(
  name='GetTopChannelsResponse',
  full_name='grpc.channelz.v1.GetTopChannelsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='grpc.channelz.v1.GetTopChannelsResponse.channel', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='grpc.channelz.v1.GetTopChannelsResponse.end', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4907,
  serialized_end=4988,
)


_GETSERVERSREQUEST = _descriptor.Descriptor(
  name='GetServersRequest',
  full_name='grpc.channelz.v1.GetServersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_server_id', full_name='grpc.channelz.v1.GetServersRequest.start_server_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='grpc.channelz.v1.GetServersRequest.max_results', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4990,
  serialized_end=5055,
)


_GETSERVERSRESPONSE = _descriptor.Descriptor(
  name='GetServersResponse',
  full_name='grpc.channelz.v1.GetServersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server', full_name='grpc.channelz.v1.GetServersResponse.server', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='grpc.channelz.v1.GetServersResponse.end', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5057,
  serialized_end=5132,
)


_GETSERVERREQUEST = _descriptor.Descriptor(
  name='GetServerRequest',
  full_name='grpc.channelz.v1.GetServerRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_id', full_name='grpc.channelz.v1.GetServerRequest.server_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5134,
  serialized_end=5171,
)


_GETSERVERRESPONSE = _descriptor.Descriptor(
  name='GetServerResponse',
  full_name='grpc.channelz.v1.GetServerResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server', full_name='grpc.channelz.v1.GetServerResponse.server', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5173,
  serialized_end=5234,
)


_GETSERVERSOCKETSREQUEST = _descriptor.Descriptor(
  name='GetServerSocketsRequest',
  full_name='grpc.channelz.v1.GetServerSocketsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='server_id', full_name='grpc.channelz.v1.GetServerSocketsRequest.server_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_socket_id', full_name='grpc.channelz.v1.GetServerSocketsRequest.start_socket_id', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_results', full_name='grpc.channelz.v1.GetServerSocketsRequest.max_results', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5236,
  serialized_end=5326,
)


_GETSERVERSOCKETSRESPONSE = _descriptor.Descriptor(
  name='GetServerSocketsResponse',
  full_name='grpc.channelz.v1.GetServerSocketsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket_ref', full_name='grpc.channelz.v1.GetServerSocketsResponse.socket_ref', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end', full_name='grpc.channelz.v1.GetServerSocketsResponse.end', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5328,
  serialized_end=5416,
)


_GETCHANNELREQUEST = _descriptor.Descriptor(
  name='GetChannelRequest',
  full_name='grpc.channelz.v1.GetChannelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel_id', full_name='grpc.channelz.v1.GetChannelRequest.channel_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5418,
  serialized_end=5457,
)


_GETCHANNELRESPONSE = _descriptor.Descriptor(
  name='GetChannelResponse',
  full_name='grpc.channelz.v1.GetChannelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='channel', full_name='grpc.channelz.v1.GetChannelResponse.channel', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5459,
  serialized_end=5523,
)


_GETSUBCHANNELREQUEST = _descriptor.Descriptor(
  name='GetSubchannelRequest',
  full_name='grpc.channelz.v1.GetSubchannelRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subchannel_id', full_name='grpc.channelz.v1.GetSubchannelRequest.subchannel_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5525,
  serialized_end=5570,
)


_GETSUBCHANNELRESPONSE = _descriptor.Descriptor(
  name='GetSubchannelResponse',
  full_name='grpc.channelz.v1.GetSubchannelResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subchannel', full_name='grpc.channelz.v1.GetSubchannelResponse.subchannel', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5572,
  serialized_end=5645,
)


_GETSOCKETREQUEST = _descriptor.Descriptor(
  name='GetSocketRequest',
  full_name='grpc.channelz.v1.GetSocketRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket_id', full_name='grpc.channelz.v1.GetSocketRequest.socket_id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='summary', full_name='grpc.channelz.v1.GetSocketRequest.summary', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5647,
  serialized_end=5701,
)


_GETSOCKETRESPONSE = _descriptor.Descriptor(
  name='GetSocketResponse',
  full_name='grpc.channelz.v1.GetSocketResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='socket', full_name='grpc.channelz.v1.GetSocketResponse.socket', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5703,
  serialized_end=5764,
)

_CHANNEL.fields_by_name['ref'].message_type = _CHANNELREF
_CHANNEL.fields_by_name['data'].message_type = _CHANNELDATA
_CHANNEL.fields_by_name['channel_ref'].message_type = _CHANNELREF
_CHANNEL.fields_by_name['subchannel_ref'].message_type = _SUBCHANNELREF
_CHANNEL.fields_by_name['socket_ref'].message_type = _SOCKETREF
_SUBCHANNEL.fields_by_name['ref'].message_type = _SUBCHANNELREF
_SUBCHANNEL.fields_by_name['data'].message_type = _CHANNELDATA
_SUBCHANNEL.fields_by_name['channel_ref'].message_type = _CHANNELREF
_SUBCHANNEL.fields_by_name['subchannel_ref'].message_type = _SUBCHANNELREF
_SUBCHANNEL.fields_by_name['socket_ref'].message_type = _SOCKETREF
_CHANNELCONNECTIVITYSTATE.fields_by_name['state'].enum_type = _CHANNELCONNECTIVITYSTATE_STATE
_CHANNELCONNECTIVITYSTATE_STATE.containing_type = _CHANNELCONNECTIVITYSTATE
_CHANNELDATA.fields_by_name['state'].message_type = _CHANNELCONNECTIVITYSTATE
_CHANNELDATA.fields_by_name['trace'].message_type = _CHANNELTRACE
_CHANNELDATA.fields_by_name['last_call_started_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CHANNELTRACEEVENT.fields_by_name['severity'].enum_type = _CHANNELTRACEEVENT_SEVERITY
_CHANNELTRACEEVENT.fields_by_name['timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CHANNELTRACEEVENT.fields_by_name['channel_ref'].message_type = _CHANNELREF
_CHANNELTRACEEVENT.fields_by_name['subchannel_ref'].message_type = _SUBCHANNELREF
_CHANNELTRACEEVENT_SEVERITY.containing_type = _CHANNELTRACEEVENT
_CHANNELTRACEEVENT.oneofs_by_name['child_ref'].fields.append(
  _CHANNELTRACEEVENT.fields_by_name['channel_ref'])
_CHANNELTRACEEVENT.fields_by_name['channel_ref'].containing_oneof = _CHANNELTRACEEVENT.oneofs_by_name['child_ref']
_CHANNELTRACEEVENT.oneofs_by_name['child_ref'].fields.append(
  _CHANNELTRACEEVENT.fields_by_name['subchannel_ref'])
_CHANNELTRACEEVENT.fields_by_name['subchannel_ref'].containing_oneof = _CHANNELTRACEEVENT.oneofs_by_name['child_ref']
_CHANNELTRACE.fields_by_name['creation_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CHANNELTRACE.fields_by_name['events'].message_type = _CHANNELTRACEEVENT
_SERVER.fields_by_name['ref'].message_type = _SERVERREF
_SERVER.fields_by_name['data'].message_type = _SERVERDATA
_SERVER.fields_by_name['listen_socket'].message_type = _SOCKETREF
_SERVERDATA.fields_by_name['trace'].message_type = _CHANNELTRACE
_SERVERDATA.fields_by_name['last_call_started_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SOCKET.fields_by_name['ref'].message_type = _SOCKETREF
_SOCKET.fields_by_name['data'].message_type = _SOCKETDATA
_SOCKET.fields_by_name['local'].message_type = _ADDRESS
_SOCKET.fields_by_name['remote'].message_type = _ADDRESS
_SOCKET.fields_by_name['security'].message_type = _SECURITY
_SOCKETDATA.fields_by_name['last_local_stream_created_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SOCKETDATA.fields_by_name['last_remote_stream_created_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SOCKETDATA.fields_by_name['last_message_sent_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SOCKETDATA.fields_by_name['last_message_received_timestamp'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_SOCKETDATA.fields_by_name['local_flow_control_window'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SOCKETDATA.fields_by_name['remote_flow_control_window'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SOCKETDATA.fields_by_name['option'].message_type = _SOCKETOPTION
_ADDRESS_TCPIPADDRESS.containing_type = _ADDRESS
_ADDRESS_UDSADDRESS.containing_type = _ADDRESS
_ADDRESS_OTHERADDRESS.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_ADDRESS_OTHERADDRESS.containing_type = _ADDRESS
_ADDRESS.fields_by_name['tcpip_address'].message_type = _ADDRESS_TCPIPADDRESS
_ADDRESS.fields_by_name['uds_address'].message_type = _ADDRESS_UDSADDRESS
_ADDRESS.fields_by_name['other_address'].message_type = _ADDRESS_OTHERADDRESS
_ADDRESS.oneofs_by_name['address'].fields.append(
  _ADDRESS.fields_by_name['tcpip_address'])
_ADDRESS.fields_by_name['tcpip_address'].containing_oneof = _ADDRESS.oneofs_by_name['address']
_ADDRESS.oneofs_by_name['address'].fields.append(
  _ADDRESS.fields_by_name['uds_address'])
_ADDRESS.fields_by_name['uds_address'].containing_oneof = _ADDRESS.oneofs_by_name['address']
_ADDRESS.oneofs_by_name['address'].fields.append(
  _ADDRESS.fields_by_name['other_address'])
_ADDRESS.fields_by_name['other_address'].containing_oneof = _ADDRESS.oneofs_by_name['address']
_SECURITY_TLS.containing_type = _SECURITY
_SECURITY_TLS.oneofs_by_name['cipher_suite'].fields.append(
  _SECURITY_TLS.fields_by_name['standard_name'])
_SECURITY_TLS.fields_by_name['standard_name'].containing_oneof = _SECURITY_TLS.oneofs_by_name['cipher_suite']
_SECURITY_TLS.oneofs_by_name['cipher_suite'].fields.append(
  _SECURITY_TLS.fields_by_name['other_name'])
_SECURITY_TLS.fields_by_name['other_name'].containing_oneof = _SECURITY_TLS.oneofs_by_name['cipher_suite']
_SECURITY_OTHERSECURITY.fields_by_name['value'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SECURITY_OTHERSECURITY.containing_type = _SECURITY
_SECURITY.fields_by_name['tls'].message_type = _SECURITY_TLS
_SECURITY.fields_by_name['other'].message_type = _SECURITY_OTHERSECURITY
_SECURITY.oneofs_by_name['model'].fields.append(
  _SECURITY.fields_by_name['tls'])
_SECURITY.fields_by_name['tls'].containing_oneof = _SECURITY.oneofs_by_name['model']
_SECURITY.oneofs_by_name['model'].fields.append(
  _SECURITY.fields_by_name['other'])
_SECURITY.fields_by_name['other'].containing_oneof = _SECURITY.oneofs_by_name['model']
_SOCKETOPTION.fields_by_name['additional'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_SOCKETOPTIONTIMEOUT.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SOCKETOPTIONLINGER.fields_by_name['duration'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_GETTOPCHANNELSRESPONSE.fields_by_name['channel'].message_type = _CHANNEL
_GETSERVERSRESPONSE.fields_by_name['server'].message_type = _SERVER
_GETSERVERRESPONSE.fields_by_name['server'].message_type = _SERVER
_GETSERVERSOCKETSRESPONSE.fields_by_name['socket_ref'].message_type = _SOCKETREF
_GETCHANNELRESPONSE.fields_by_name['channel'].message_type = _CHANNEL
_GETSUBCHANNELRESPONSE.fields_by_name['subchannel'].message_type = _SUBCHANNEL
_GETSOCKETRESPONSE.fields_by_name['socket'].message_type = _SOCKET
DESCRIPTOR.message_types_by_name['Channel'] = _CHANNEL
DESCRIPTOR.message_types_by_name['Subchannel'] = _SUBCHANNEL
DESCRIPTOR.message_types_by_name['ChannelConnectivityState'] = _CHANNELCONNECTIVITYSTATE
DESCRIPTOR.message_types_by_name['ChannelData'] = _CHANNELDATA
DESCRIPTOR.message_types_by_name['ChannelTraceEvent'] = _CHANNELTRACEEVENT
DESCRIPTOR.message_types_by_name['ChannelTrace'] = _CHANNELTRACE
DESCRIPTOR.message_types_by_name['ChannelRef'] = _CHANNELREF
DESCRIPTOR.message_types_by_name['SubchannelRef'] = _SUBCHANNELREF
DESCRIPTOR.message_types_by_name['SocketRef'] = _SOCKETREF
DESCRIPTOR.message_types_by_name['ServerRef'] = _SERVERREF
DESCRIPTOR.message_types_by_name['Server'] = _SERVER
DESCRIPTOR.message_types_by_name['ServerData'] = _SERVERDATA
DESCRIPTOR.message_types_by_name['Socket'] = _SOCKET
DESCRIPTOR.message_types_by_name['SocketData'] = _SOCKETDATA
DESCRIPTOR.message_types_by_name['Address'] = _ADDRESS
DESCRIPTOR.message_types_by_name['Security'] = _SECURITY
DESCRIPTOR.message_types_by_name['SocketOption'] = _SOCKETOPTION
DESCRIPTOR.message_types_by_name['SocketOptionTimeout'] = _SOCKETOPTIONTIMEOUT
DESCRIPTOR.message_types_by_name['SocketOptionLinger'] = _SOCKETOPTIONLINGER
DESCRIPTOR.message_types_by_name['SocketOptionTcpInfo'] = _SOCKETOPTIONTCPINFO
DESCRIPTOR.message_types_by_name['GetTopChannelsRequest'] = _GETTOPCHANNELSREQUEST
DESCRIPTOR.message_types_by_name['GetTopChannelsResponse'] = _GETTOPCHANNELSRESPONSE
DESCRIPTOR.message_types_by_name['GetServersRequest'] = _GETSERVERSREQUEST
DESCRIPTOR.message_types_by_name['GetServersResponse'] = _GETSERVERSRESPONSE
DESCRIPTOR.message_types_by_name['GetServerRequest'] = _GETSERVERREQUEST
DESCRIPTOR.message_types_by_name['GetServerResponse'] = _GETSERVERRESPONSE
DESCRIPTOR.message_types_by_name['GetServerSocketsRequest'] = _GETSERVERSOCKETSREQUEST
DESCRIPTOR.message_types_by_name['GetServerSocketsResponse'] = _GETSERVERSOCKETSRESPONSE
DESCRIPTOR.message_types_by_name['GetChannelRequest'] = _GETCHANNELREQUEST
DESCRIPTOR.message_types_by_name['GetChannelResponse'] = _GETCHANNELRESPONSE
DESCRIPTOR.message_types_by_name['GetSubchannelRequest'] = _GETSUBCHANNELREQUEST
DESCRIPTOR.message_types_by_name['GetSubchannelResponse'] = _GETSUBCHANNELRESPONSE
DESCRIPTOR.message_types_by_name['GetSocketRequest'] = _GETSOCKETREQUEST
DESCRIPTOR.message_types_by_name['GetSocketResponse'] = _GETSOCKETRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Channel = _reflection.GeneratedProtocolMessageType('Channel', (_message.Message,), {
  'DESCRIPTOR' : _CHANNEL,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Channel)
  })
_sym_db.RegisterMessage(Channel)

Subchannel = _reflection.GeneratedProtocolMessageType('Subchannel', (_message.Message,), {
  'DESCRIPTOR' : _SUBCHANNEL,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Subchannel)
  })
_sym_db.RegisterMessage(Subchannel)

ChannelConnectivityState = _reflection.GeneratedProtocolMessageType('ChannelConnectivityState', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELCONNECTIVITYSTATE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.ChannelConnectivityState)
  })
_sym_db.RegisterMessage(ChannelConnectivityState)

ChannelData = _reflection.GeneratedProtocolMessageType('ChannelData', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELDATA,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.ChannelData)
  })
_sym_db.RegisterMessage(ChannelData)

ChannelTraceEvent = _reflection.GeneratedProtocolMessageType('ChannelTraceEvent', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELTRACEEVENT,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.ChannelTraceEvent)
  })
_sym_db.RegisterMessage(ChannelTraceEvent)

ChannelTrace = _reflection.GeneratedProtocolMessageType('ChannelTrace', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELTRACE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.ChannelTrace)
  })
_sym_db.RegisterMessage(ChannelTrace)

ChannelRef = _reflection.GeneratedProtocolMessageType('ChannelRef', (_message.Message,), {
  'DESCRIPTOR' : _CHANNELREF,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.ChannelRef)
  })
_sym_db.RegisterMessage(ChannelRef)

SubchannelRef = _reflection.GeneratedProtocolMessageType('SubchannelRef', (_message.Message,), {
  'DESCRIPTOR' : _SUBCHANNELREF,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.SubchannelRef)
  })
_sym_db.RegisterMessage(SubchannelRef)

SocketRef = _reflection.GeneratedProtocolMessageType('SocketRef', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETREF,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.SocketRef)
  })
_sym_db.RegisterMessage(SocketRef)

ServerRef = _reflection.GeneratedProtocolMessageType('ServerRef', (_message.Message,), {
  'DESCRIPTOR' : _SERVERREF,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.ServerRef)
  })
_sym_db.RegisterMessage(ServerRef)

Server = _reflection.GeneratedProtocolMessageType('Server', (_message.Message,), {
  'DESCRIPTOR' : _SERVER,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Server)
  })
_sym_db.RegisterMessage(Server)

ServerData = _reflection.GeneratedProtocolMessageType('ServerData', (_message.Message,), {
  'DESCRIPTOR' : _SERVERDATA,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.ServerData)
  })
_sym_db.RegisterMessage(ServerData)

Socket = _reflection.GeneratedProtocolMessageType('Socket', (_message.Message,), {
  'DESCRIPTOR' : _SOCKET,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Socket)
  })
_sym_db.RegisterMessage(Socket)

SocketData = _reflection.GeneratedProtocolMessageType('SocketData', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETDATA,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.SocketData)
  })
_sym_db.RegisterMessage(SocketData)

Address = _reflection.GeneratedProtocolMessageType('Address', (_message.Message,), {

  'TcpIpAddress' : _reflection.GeneratedProtocolMessageType('TcpIpAddress', (_message.Message,), {
    'DESCRIPTOR' : _ADDRESS_TCPIPADDRESS,
    '__module__' : 'grpclib.channelz.v1.channelz_pb2'
    # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Address.TcpIpAddress)
    })
  ,

  'UdsAddress' : _reflection.GeneratedProtocolMessageType('UdsAddress', (_message.Message,), {
    'DESCRIPTOR' : _ADDRESS_UDSADDRESS,
    '__module__' : 'grpclib.channelz.v1.channelz_pb2'
    # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Address.UdsAddress)
    })
  ,

  'OtherAddress' : _reflection.GeneratedProtocolMessageType('OtherAddress', (_message.Message,), {
    'DESCRIPTOR' : _ADDRESS_OTHERADDRESS,
    '__module__' : 'grpclib.channelz.v1.channelz_pb2'
    # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Address.OtherAddress)
    })
  ,
  'DESCRIPTOR' : _ADDRESS,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Address)
  })
_sym_db.RegisterMessage(Address)
_sym_db.RegisterMessage(Address.TcpIpAddress)
_sym_db.RegisterMessage(Address.UdsAddress)
_sym_db.RegisterMessage(Address.OtherAddress)

Security = _reflection.GeneratedProtocolMessageType('Security', (_message.Message,), {

  'Tls' : _reflection.GeneratedProtocolMessageType('Tls', (_message.Message,), {
    'DESCRIPTOR' : _SECURITY_TLS,
    '__module__' : 'grpclib.channelz.v1.channelz_pb2'
    # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Security.Tls)
    })
  ,

  'OtherSecurity' : _reflection.GeneratedProtocolMessageType('OtherSecurity', (_message.Message,), {
    'DESCRIPTOR' : _SECURITY_OTHERSECURITY,
    '__module__' : 'grpclib.channelz.v1.channelz_pb2'
    # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Security.OtherSecurity)
    })
  ,
  'DESCRIPTOR' : _SECURITY,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.Security)
  })
_sym_db.RegisterMessage(Security)
_sym_db.RegisterMessage(Security.Tls)
_sym_db.RegisterMessage(Security.OtherSecurity)

SocketOption = _reflection.GeneratedProtocolMessageType('SocketOption', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETOPTION,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.SocketOption)
  })
_sym_db.RegisterMessage(SocketOption)

SocketOptionTimeout = _reflection.GeneratedProtocolMessageType('SocketOptionTimeout', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETOPTIONTIMEOUT,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.SocketOptionTimeout)
  })
_sym_db.RegisterMessage(SocketOptionTimeout)

SocketOptionLinger = _reflection.GeneratedProtocolMessageType('SocketOptionLinger', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETOPTIONLINGER,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.SocketOptionLinger)
  })
_sym_db.RegisterMessage(SocketOptionLinger)

SocketOptionTcpInfo = _reflection.GeneratedProtocolMessageType('SocketOptionTcpInfo', (_message.Message,), {
  'DESCRIPTOR' : _SOCKETOPTIONTCPINFO,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.SocketOptionTcpInfo)
  })
_sym_db.RegisterMessage(SocketOptionTcpInfo)

GetTopChannelsRequest = _reflection.GeneratedProtocolMessageType('GetTopChannelsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTOPCHANNELSREQUEST,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetTopChannelsRequest)
  })
_sym_db.RegisterMessage(GetTopChannelsRequest)

GetTopChannelsResponse = _reflection.GeneratedProtocolMessageType('GetTopChannelsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTOPCHANNELSRESPONSE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetTopChannelsResponse)
  })
_sym_db.RegisterMessage(GetTopChannelsResponse)

GetServersRequest = _reflection.GeneratedProtocolMessageType('GetServersRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERSREQUEST,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetServersRequest)
  })
_sym_db.RegisterMessage(GetServersRequest)

GetServersResponse = _reflection.GeneratedProtocolMessageType('GetServersResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERSRESPONSE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetServersResponse)
  })
_sym_db.RegisterMessage(GetServersResponse)

GetServerRequest = _reflection.GeneratedProtocolMessageType('GetServerRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERREQUEST,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetServerRequest)
  })
_sym_db.RegisterMessage(GetServerRequest)

GetServerResponse = _reflection.GeneratedProtocolMessageType('GetServerResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERRESPONSE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetServerResponse)
  })
_sym_db.RegisterMessage(GetServerResponse)

GetServerSocketsRequest = _reflection.GeneratedProtocolMessageType('GetServerSocketsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERSOCKETSREQUEST,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetServerSocketsRequest)
  })
_sym_db.RegisterMessage(GetServerSocketsRequest)

GetServerSocketsResponse = _reflection.GeneratedProtocolMessageType('GetServerSocketsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVERSOCKETSRESPONSE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetServerSocketsResponse)
  })
_sym_db.RegisterMessage(GetServerSocketsResponse)

GetChannelRequest = _reflection.GeneratedProtocolMessageType('GetChannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCHANNELREQUEST,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetChannelRequest)
  })
_sym_db.RegisterMessage(GetChannelRequest)

GetChannelResponse = _reflection.GeneratedProtocolMessageType('GetChannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCHANNELRESPONSE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetChannelResponse)
  })
_sym_db.RegisterMessage(GetChannelResponse)

GetSubchannelRequest = _reflection.GeneratedProtocolMessageType('GetSubchannelRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSUBCHANNELREQUEST,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetSubchannelRequest)
  })
_sym_db.RegisterMessage(GetSubchannelRequest)

GetSubchannelResponse = _reflection.GeneratedProtocolMessageType('GetSubchannelResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSUBCHANNELRESPONSE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetSubchannelResponse)
  })
_sym_db.RegisterMessage(GetSubchannelResponse)

GetSocketRequest = _reflection.GeneratedProtocolMessageType('GetSocketRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSOCKETREQUEST,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetSocketRequest)
  })
_sym_db.RegisterMessage(GetSocketRequest)

GetSocketResponse = _reflection.GeneratedProtocolMessageType('GetSocketResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSOCKETRESPONSE,
  '__module__' : 'grpclib.channelz.v1.channelz_pb2'
  # @@protoc_insertion_point(class_scope:grpc.channelz.v1.GetSocketResponse)
  })
_sym_db.RegisterMessage(GetSocketResponse)


DESCRIPTOR._options = None

_CHANNELZ = _descriptor.ServiceDescriptor(
  name='Channelz',
  full_name='grpc.channelz.v1.Channelz',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=5767,
  serialized_end=6433,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetTopChannels',
    full_name='grpc.channelz.v1.Channelz.GetTopChannels',
    index=0,
    containing_service=None,
    input_type=_GETTOPCHANNELSREQUEST,
    output_type=_GETTOPCHANNELSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetServers',
    full_name='grpc.channelz.v1.Channelz.GetServers',
    index=1,
    containing_service=None,
    input_type=_GETSERVERSREQUEST,
    output_type=_GETSERVERSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetServer',
    full_name='grpc.channelz.v1.Channelz.GetServer',
    index=2,
    containing_service=None,
    input_type=_GETSERVERREQUEST,
    output_type=_GETSERVERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetServerSockets',
    full_name='grpc.channelz.v1.Channelz.GetServerSockets',
    index=3,
    containing_service=None,
    input_type=_GETSERVERSOCKETSREQUEST,
    output_type=_GETSERVERSOCKETSRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetChannel',
    full_name='grpc.channelz.v1.Channelz.GetChannel',
    index=4,
    containing_service=None,
    input_type=_GETCHANNELREQUEST,
    output_type=_GETCHANNELRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSubchannel',
    full_name='grpc.channelz.v1.Channelz.GetSubchannel',
    index=5,
    containing_service=None,
    input_type=_GETSUBCHANNELREQUEST,
    output_type=_GETSUBCHANNELRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetSocket',
    full_name='grpc.channelz.v1.Channelz.GetSocket',
    index=6,
    containing_service=None,
    input_type=_GETSOCKETREQUEST,
    output_type=_GETSOCKETRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_CHANNELZ)

DESCRIPTOR.services_by_name['Channelz'] = _CHANNELZ

# @@protoc_insertion_point(module_scope)



from ..const import Status
from ..server import Stream
from ..exceptions import GRPCError

from .v1.channelz_pb2 import GetTopChannelsRequest, GetTopChannelsResponse
from .v1.channelz_pb2 import GetServersRequest, GetServersResponse
from .v1.channelz_pb2 import GetServerRequest, GetServerResponse
from .v1.channelz_pb2 import GetServerSocketsRequest, GetServerSocketsResponse
from .v1.channelz_pb2 import GetChannelRequest, GetChannelResponse
from .v1.channelz_pb2 import GetSubchannelRequest, GetSubchannelResponse
from .v1.channelz_pb2 import GetSocketRequest, GetSocketResponse
from .v1.channelz_grpc import ChannelzBase


class Channelz(ChannelzBase):

    async def GetTopChannels(
        self, stream: 'Stream[GetTopChannelsRequest, GetTopChannelsResponse]',
    ) -> None:
        raise GRPCError(Status.UNIMPLEMENTED)

    async def GetServers(
        self, stream: 'Stream[GetServersRequest, GetServersResponse]',
    ) -> None:
        raise GRPCError(Status.UNIMPLEMENTED)

    async def GetServer(
        self, stream: 'Stream[GetServerRequest, GetServerResponse]',
    ) -> None:
        raise GRPCError(Status.UNIMPLEMENTED)

    async def GetServerSockets(
        self,
        stream: 'Stream[GetServerSocketsRequest, GetServerSocketsResponse]',
    ) -> None:
        raise GRPCError(Status.UNIMPLEMENTED)

    async def GetChannel(
        self, stream: 'Stream[GetChannelRequest, GetChannelResponse]',
    ) -> None:
        raise GRPCError(Status.UNIMPLEMENTED)

    async def GetSubchannel(
        self, stream: 'Stream[GetSubchannelRequest, GetSubchannelResponse]',
    ) -> None:
        raise GRPCError(Status.UNIMPLEMENTED)

    async def GetSocket(
        self, stream: 'Stream[GetSocketRequest, GetSocketResponse]',
    ) -> None:
        raise GRPCError(Status.UNIMPLEMENTED)
